@@ -1,16 +1,18 @@
+# -*- coding:utf-8 -*-
+from AccessControl import allow_type, ModuleSecurityInfo
+from RestrictedPython import compile_restricted
+
+import AccessControl.ZopeGuards as ZopeGuards
 import datetime
 import re
 
-import AccessControl.ZopeGuards as ZopeGuards
-from AccessControl import ModuleSecurityInfo, allow_type
-from RestrictedPython import compile_restricted
 
 # Make useful modules visible
-for name in ('datetime', 'time', 're'):
-    ModuleSecurityInfo(name).setDefaultAccess('allow')
+for name in ("datetime", "time", "re"):
+    ModuleSecurityInfo(name).setDefaultAccess("allow")
 # Include their key types
-allow_type(type(re.compile('')))
-allow_type(type(re.match('x', 'x')))
+allow_type(type(re.compile("")))
+allow_type(type(re.match("x", "x")))
 allow_type(type(datetime.date))  # Make sure we get class methods
 allow_type(type(datetime.datetime))  # class methods
 allow_type(type(datetime.date(2017, 1, 1)))
@@ -25,10 +27,10 @@ class PyScript(object):
     def __init__(self, code):
         self.code = compile_restricted(code, "<string>", "exec")
 
-    def execute(self, locals=None, output=None):
+    def execute(self, my_locals=None, output=None):
         my_globals = ZopeGuards.get_safe_globals()
-        my_globals['_getattr_'] = ZopeGuards.guarded_getattr
-        if locals is None:
-            locals = {}
-        exec self.code in my_globals, locals
-        return locals
+        my_globals["_getattr_"] = ZopeGuards.guarded_getattr
+        if my_locals is None:
+            my_locals = {}
+        exec(self.code, my_globals, my_locals)
+        return my_locals
